#ifndef __DALI_TOOLKIT_DOC_H__
#define __DALI_TOOLKIT_DOC_H__

/**
 * @defgroup dali DALi
 * @ingroup CAPI_UI_FRAMEWORK
 *
 * @brief DALi is a cross-platform 3D UI Toolkit for embedded systems.
 *
 * @section dali-overview Overview
 * DALi's 3D user interface engine enables you to create rich and high-performance
 * UI applications. DALi is based on OpenGL ES 2.0, but provides a clean
 * cross-platform C++ framework.
 * This means that you can use high-level DALi APIs instead of accessing
 * low-level OpenGL APIs directly.
 * <ul>
 * <li>DALi Core: This module provides scene graph-based rendering, animation, and event handling.</li>
 * <li>DALi Adaptor: This module is a platform adaptation layer.</li>
 * <li>DALi Toolkit: This module provides UI components and various effects on top of the DALi Core.</li>
 * </ul>
 *
 * @defgroup dali_toolkit DALi Toolkit
 * @ingroup dali
 *
 * @brief This module provides UI components and various effects on top of the DALi Core.
 *
 * @{
 *   @defgroup dali_toolkit_accessibility_manager Accessibility Manager
 *   @brief AccessibilityManager manages a accessibility focus chain.

 *   @defgroup dali_toolkit_controls Controls
 *   @brief Controls are interactive components for layouting the user interface.

 *   @{
 *     @defgroup dali_toolkit_controls_alignment Alignment
 *     @brief Alignment is a container which provides an easy way to align other actors inside its boundary.

 *     @defgroup dali_toolkit_controls_buttons Buttons
 *     @brief Button is a small object on UI that you can press.

 *     @defgroup dali_toolkit_controls_gaussian_blur_view Gaussian Blur View
 *     @brief GaussianBlurView provides a render process that blurs an image.

 *     @defgroup dali_toolkit_controls_image_view Image View
 *     @brief ImageView is a control displying an image.

 *     @defgroup dali_toolkit_controls_scroll_bar Scroll Bar
 *     @brief ScrollBar control.

 *     @defgroup dali_toolkit_controls_scrollable Scrollable
 *     @brief Scrollable container controls.

 *     @{
 *       @defgroup dali_toolkit_controls_item_view Item View
 *       @brief ItemView class is a scrollable container that can contain many items.

 *       @defgroup dali_toolkit_controls_scroll_view Scroll View
 *       @brief ScrollView class provides scrollable view which contains actors and can be scrolled automatically or manually by panning.

 *     @}
 *     @defgroup dali_toolkit_controls_table_view Table View
 *     @brief TableView class is a layout container for aligning child actors in a grid like layout.

 *     @defgroup dali_toolkit_controls_text_controls Text Controls
 *     @brief Controls for displaying text or text input.

 *   @}
 *   @defgroup dali_toolkit_focus_manager Focus Manager
 *   @brief Classes for handling keyboard navigation and maintaining the two dimensional keyboard focus chain.

 * @}
 */


#endif  /* __DALI_TOOLKIT_DOC_H__ */
